This is the mail archive of the glibc-cvs@sourceware.org mailing list for the glibc project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

GNU C Library master sources branch master updated. glibc-2.18-364-g1484e65


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU C Library master sources".

The branch, master has been updated
       via  1484e65736f4cab27e5051e0f06be8470e69af82 (commit)
      from  cd3e2ac55e6848bc725a20978a4c2a7ab766bd86 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://sourceware.org/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=1484e65736f4cab27e5051e0f06be8470e69af82

commit 1484e65736f4cab27e5051e0f06be8470e69af82
Author: Joseph Myers <joseph@codesourcery.com>
Date:   Mon Nov 4 15:43:57 2013 +0000

    Define __STDC_IEC_559* based on __GCC_IEC_559*.

diff --git a/ChangeLog b/ChangeLog
index 4d43eb0..1fd2463 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+2013-11-04  Joseph Myers  <joseph@codesourcery.com>
+
+	* include/stdc-predef.h [__GCC_IEC_559] (__STDC_IEC_559__): Define
+	depending on [__GCC_IEC_559 > 0].
+	[__GCC_IEC_559_COMPLEX] (__STDC_IEC_559_COMPLEX__): Define
+	depending on [__GCC_IEC_559_COMPLEX > 0].
+
 2013-11-03  Chris Leonard  <cjl@sugarlabs.org>
 
 	* locale/iso-639.def: Add Quechua, Southern (quz) and Silesian (szl)
diff --git a/include/stdc-predef.h b/include/stdc-predef.h
index b9c9967..f8cb2cb 100644
--- a/include/stdc-predef.h
+++ b/include/stdc-predef.h
@@ -26,9 +26,28 @@
    explicitly includes a system header.  GCC knows the name of this
    header in order to preinclude it.  */
 
-/* We do support the IEC 559 math functionality, real and complex.  */
-#define __STDC_IEC_559__		1
-#define __STDC_IEC_559_COMPLEX__	1
+/* glibc's intent is to support the IEC 559 math functionality, real
+   and complex.  If the GCC (4.9 and later) predefined macros
+   specifying compiler intent are available, use them to determine
+   whether the overall intent is to support these features; otherwise,
+   presume an older compiler has intent to support these features and
+   define these macros by default.  */
+
+#ifdef __GCC_IEC_559
+# if __GCC_IEC_559 > 0
+#  define __STDC_IEC_559__		1
+# endif
+#else
+# define __STDC_IEC_559__		1
+#endif
+
+#ifdef __GCC_IEC_559_COMPLEX
+# if __GCC_IEC_559_COMPLEX > 0
+#  define __STDC_IEC_559_COMPLEX__	1
+# endif
+#else
+# define __STDC_IEC_559_COMPLEX__	1
+#endif
 
 /* wchar_t uses ISO/IEC 10646 (2nd ed., published 2011-03-15) /
    Unicode 6.0.  */

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog             |    7 +++++++
 include/stdc-predef.h |   25 ++++++++++++++++++++++---
 2 files changed, 29 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
GNU C Library master sources


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]